[Libreoffice-commits] core.git: 2 commits - formula/source include/formula sc/source

Laurent Charrière lcharriere at gmail.com
Sun Jan 11 22:55:47 PST 2015


 formula/source/core/api/FormulaCompiler.cxx    |    4 ++--
 formula/source/core/api/token.cxx              |    2 +-
 formula/source/core/resource/core_resource.src |   16 ++++++++--------
 include/formula/compiler.hrc                   |    4 ++--
 include/formula/opcode.hxx                     |    4 ++--
 sc/source/core/inc/interpre.hxx                |    4 ++--
 sc/source/core/opencl/formulagroupcl.cxx       |    4 ++--
 sc/source/core/tool/interpr2.cxx               |    4 ++--
 sc/source/core/tool/interpr4.cxx               |    4 ++--
 sc/source/core/tool/token.cxx                  |    4 ++--
 sc/source/filter/excel/xlformula.cxx           |    4 ++--
 sc/source/filter/lotus/lotform.cxx             |   14 +++++++-------
 sc/source/filter/qpro/qproform.cxx             |    4 ++--
 sc/source/ui/src/scfuncs.src                   |    8 ++++----
 14 files changed, 40 insertions(+), 40 deletions(-)

New commits:
commit c6d3405d9cf75adc8ae9f8b2cca2dfd2c9de7d7d
Author: Laurent Charrière <lcharriere at gmail.com>
Date:   Fri Jan 9 13:26:48 2015 +0100

    fdo#85818: rename RMZ to PMT
    
    Change-Id: I952d4cee42c9a6256589a32f4acb6a6fc70ef443
    Reviewed-on: https://gerrit.libreoffice.org/13830
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Noel Grandin <noelgrandin at gmail.com>

diff --git a/formula/source/core/api/FormulaCompiler.cxx b/formula/source/core/api/FormulaCompiler.cxx
index 50bfd82..5d289fb 100644
--- a/formula/source/core/api/FormulaCompiler.cxx
+++ b/formula/source/core/api/FormulaCompiler.cxx
@@ -98,7 +98,7 @@ short lcl_GetRetFormat( OpCode eOpCode )
         case ocDB:
         case ocVBD:
         case ocSLN:
-        case ocRMZ:
+        case ocPMT:
         case ocZW:
         case ocIpmt:
         case ocPpmt:
diff --git a/formula/source/core/api/token.cxx b/formula/source/core/api/token.cxx
index c6f4a2f..82cdcf2 100644
--- a/formula/source/core/api/token.cxx
+++ b/formula/source/core/api/token.cxx
@@ -1254,7 +1254,7 @@ bool FormulaMissingContext::AddMissing( FormulaTokenArray *pNewArr, const Missin
                         return AddDefaultArg( pNewArr, 1, 2.0 );
                     case ocBetaDist:
                     case ocBetaInv:
-                    case ocRMZ:     // PMT
+                    case ocPMT:
                         return AddDefaultArg( pNewArr, 3, 0.0 );
                     case ocIpmt:
                     case ocPpmt:
diff --git a/formula/source/core/resource/core_resource.src b/formula/source/core/resource/core_resource.src
index c64be1f..81cafdf 100644
--- a/formula/source/core/resource/core_resource.src
+++ b/formula/source/core/resource/core_resource.src
@@ -217,7 +217,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH_ODFF
     String SC_OPCODE_VBD { Text = "VDB" ; };
     String SC_OPCODE_DURATION { Text = "PDURATION" ; };
     String SC_OPCODE_SLN { Text = "SLN" ; };
-    String SC_OPCODE_RMZ { Text = "PMT" ; };
+    String SC_OPCODE_PMT { Text = "PMT" ; };
     String SC_OPCODE_COLUMNS { Text = "COLUMNS" ; };
     String SC_OPCODE_ROWS { Text = "ROWS" ; };
     String SC_OPCODE_TABLES { Text = "SHEETS" ; };
@@ -624,7 +624,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH_OOXML
     String SC_OPCODE_VBD { Text = "VDB" ; };
     String SC_OPCODE_DURATION { Text = "_xlfn.PDURATION" ; };
     String SC_OPCODE_SLN { Text = "SLN" ; };
-    String SC_OPCODE_RMZ { Text = "PMT" ; };
+    String SC_OPCODE_PMT { Text = "PMT" ; };
     String SC_OPCODE_COLUMNS { Text = "COLUMNS" ; };
     String SC_OPCODE_ROWS { Text = "ROWS" ; };
     String SC_OPCODE_TABLES { Text = "_xlfn.SHEETS" ; };
@@ -1033,7 +1033,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH
     String SC_OPCODE_VBD { Text = "VDB" ; };
     String SC_OPCODE_DURATION { Text = "DURATION" ; };
     String SC_OPCODE_SLN { Text = "SLN" ; };
-    String SC_OPCODE_RMZ { Text = "PMT" ; };
+    String SC_OPCODE_PMT { Text = "PMT" ; };
     String SC_OPCODE_COLUMNS { Text = "COLUMNS" ; };
     String SC_OPCODE_ROWS { Text = "ROWS" ; };
     String SC_OPCODE_TABLES { Text = "SHEETS" ; };
@@ -1951,7 +1951,7 @@ Resource RID_STRLIST_FUNCTION_NAMES
     {
         Text [ en-US ] = "SLN" ;
     };
-    String SC_OPCODE_RMZ
+    String SC_OPCODE_PMT
     {
         Text [ en-US ] = "PMT" ;
     };
diff --git a/include/formula/compiler.hrc b/include/formula/compiler.hrc
index bfbcc70..a512e28 100644
--- a/include/formula/compiler.hrc
+++ b/include/formula/compiler.hrc
@@ -248,7 +248,7 @@
 #define SC_OPCODE_VBD               248
 #define SC_OPCODE_DURATION          249
 #define SC_OPCODE_SLN               250
-#define SC_OPCODE_RMZ               251
+#define SC_OPCODE_PMT               251
 #define SC_OPCODE_COLUMNS           252
 #define SC_OPCODE_ROWS              253
 #define SC_OPCODE_COLUMN            254
diff --git a/include/formula/opcode.hxx b/include/formula/opcode.hxx
index 4ca9893..5349559 100644
--- a/include/formula/opcode.hxx
+++ b/include/formula/opcode.hxx
@@ -252,7 +252,7 @@ enum OpCode : sal_uInt16
         ocVBD               = SC_OPCODE_VBD,
         ocDuration          = SC_OPCODE_DURATION,
         ocSLN               = SC_OPCODE_SLN,
-        ocRMZ               = SC_OPCODE_RMZ,
+        ocPMT               = SC_OPCODE_PMT,
         ocColumns           = SC_OPCODE_COLUMNS,
         ocRows              = SC_OPCODE_ROWS,
         ocColumn            = SC_OPCODE_COLUMN,
diff --git a/sc/source/core/inc/interpre.hxx b/sc/source/core/inc/interpre.hxx
index d761a3f..6f6b75c 100644
--- a/sc/source/core/inc/interpre.hxx
+++ b/sc/source/core/inc/interpre.hxx
@@ -673,7 +673,7 @@ void ScDuration();
 void ScSLN();
 double ScGetRmz(double fZins, double fZzr, double fBw,
                        double fZw, double fF);
-void ScRMZ();
+void ScPMT();
 void ScZGZ();
 double ScGetZw(double fZins, double fZzr, double fRmz,
                       double fBw, double fF);
diff --git a/sc/source/core/opencl/formulagroupcl.cxx b/sc/source/core/opencl/formulagroupcl.cxx
index e3704bd..d9295bf 100644
--- a/sc/source/core/opencl/formulagroupcl.cxx
+++ b/sc/source/core/opencl/formulagroupcl.cxx
@@ -2262,7 +2262,7 @@ DynamicKernelSoPArguments::DynamicKernelSoPArguments(
             case ocMIRR:
                 mvSubArguments.push_back(SoPHelper(ts, ft->Children[i], new OpMIRR, nResultSize));
                 break;
-            case ocRMZ:
+            case ocPMT:
                 mvSubArguments.push_back(SoPHelper(ts, ft->Children[i], new OpPMT, nResultSize));
                 break;
             case ocRate:
diff --git a/sc/source/core/tool/interpr2.cxx b/sc/source/core/tool/interpr2.cxx
index 4cfc8ba..5a62b44 100644
--- a/sc/source/core/tool/interpr2.cxx
+++ b/sc/source/core/tool/interpr2.cxx
@@ -1464,7 +1464,7 @@ double ScInterpreter::ScGetRmz(double fRate, double fNper, double fPv,
     return -fPayment;
 }
 
-void ScInterpreter::ScRMZ()
+void ScInterpreter::ScPMT()
 {
     double nInterest, nZzr, nBw, nZw = 0, nFlag = 0;
     nFuncFmtType = NUMBERFORMAT_CURRENCY;
diff --git a/sc/source/core/tool/interpr4.cxx b/sc/source/core/tool/interpr4.cxx
index badbd9a..ea532ae 100644
--- a/sc/source/core/tool/interpr4.cxx
+++ b/sc/source/core/tool/interpr4.cxx
@@ -4028,7 +4028,7 @@ StackVar ScInterpreter::Interpret()
                 case ocVBD              : ScVDB();                      break;
                 case ocDuration         : ScDuration();                 break;
                 case ocSLN              : ScSLN();                      break;
-                case ocRMZ              : ScRMZ();                      break;
+                case ocPMT              : ScPMT();                      break;
                 case ocColumns          : ScColumns();                  break;
                 case ocRows             : ScRows();                     break;
                 case ocTables           : ScTables();                   break;
diff --git a/sc/source/core/tool/token.cxx b/sc/source/core/tool/token.cxx
index b305b8a..8d01d04 100644
--- a/sc/source/core/tool/token.cxx
+++ b/sc/source/core/tool/token.cxx
@@ -1170,7 +1170,7 @@ void ScTokenArray::CheckToken( const FormulaToken& r )
             case ocSLN:
             case ocIRR:
             case ocMIRR:
-            case ocRMZ:
+            case ocPMT:
             case ocRate:
             case ocZGZ:
             case ocPpmt:
diff --git a/sc/source/filter/excel/xlformula.cxx b/sc/source/filter/excel/xlformula.cxx
index 4deb125..01f54c8 100644
--- a/sc/source/filter/excel/xlformula.cxx
+++ b/sc/source/filter/excel/xlformula.cxx
@@ -137,7 +137,7 @@ static const XclFunctionInfo saFuncTable_2[] =
     { ocPV,                 56,     3,  5,  V, { VR }, 0, 0 },
     { ocZW,                 57,     3,  5,  V, { VR }, 0, 0 },
     { ocZZR,                58,     3,  5,  V, { VR }, 0, 0 },
-    { ocRMZ,                59,     3,  5,  V, { VR }, 0, 0 },
+    { ocPMT,                59,     3,  5,  V, { VR }, 0, 0 },
     { ocRate,               60,     3,  6,  V, { VR }, 0, 0 },
     { ocMIRR,               61,     3,  3,  V, { RA, VR }, 0, 0 },
     { ocIRR,                62,     1,  2,  V, { RA, VR }, 0, 0 },
diff --git a/sc/source/filter/qpro/qproform.cxx b/sc/source/filter/qpro/qproform.cxx
index 91f854d..2372b6a 100644
--- a/sc/source/filter/qpro/qproform.cxx
+++ b/sc/source/filter/qpro/qproform.cxx
@@ -499,7 +499,7 @@ static const struct
     { ocDBStdDevP, FT_FuncVar },
     { ocDBVarP, FT_FuncVar },
     { ocPV, FT_FuncFix3 },  // QPro Pval
-    { ocRMZ, FT_FuncFix5 }, // QPro Paymt
+    { ocPMT, FT_FuncFix5 }, // QPro Paymt
     { ocZW, FT_FuncFix3 },  // QPro Fval   // 0x80
     { ocZZR, FT_FuncFix5 },
     { ocRate, FT_FuncFix5 },
diff --git a/sc/source/ui/src/scfuncs.src b/sc/source/ui/src/scfuncs.src
index 86b7608..4b040fe 100644
--- a/sc/source/ui/src/scfuncs.src
+++ b/sc/source/ui/src/scfuncs.src
@@ -1332,8 +1332,8 @@ Resource RID_SC_FUNCTION_DESCRIPTIONS1
             Text [ en-US ] = "Type = 1 denotes due at the beginning of the period, = 0 at the end." ;
         };
     };
-     // -=*# Resource for function RMZ #*=-
-    Resource SC_OPCODE_RMZ
+     // -=*# Resource for function PMT #*=-
+    Resource SC_OPCODE_PMT
     {
         String 1 // Description
         {
commit 294b1e93f4a9e70e0699b2b42eba03eed630ec0c
Author: Laurent Charrière <lcharriere at gmail.com>
Date:   Fri Jan 9 13:22:08 2015 +0100

    fdo#85818: rename LIA to SLN
    
    Change-Id: Ifbf9be5fae60a6460596b90ce87e9ace45b2098f
    Reviewed-on: https://gerrit.libreoffice.org/13829
    Reviewed-by: Noel Grandin <noelgrandin at gmail.com>
    Tested-by: Noel Grandin <noelgrandin at gmail.com>

diff --git a/formula/source/core/api/FormulaCompiler.cxx b/formula/source/core/api/FormulaCompiler.cxx
index ec53ee6..50bfd82 100644
--- a/formula/source/core/api/FormulaCompiler.cxx
+++ b/formula/source/core/api/FormulaCompiler.cxx
@@ -97,7 +97,7 @@ short lcl_GetRetFormat( OpCode eOpCode )
         case ocDDB:
         case ocDB:
         case ocVBD:
-        case ocLIA:
+        case ocSLN:
         case ocRMZ:
         case ocZW:
         case ocIpmt:
diff --git a/formula/source/core/resource/core_resource.src b/formula/source/core/resource/core_resource.src
index 6ed8e2d..c64be1f 100644
--- a/formula/source/core/resource/core_resource.src
+++ b/formula/source/core/resource/core_resource.src
@@ -216,7 +216,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH_ODFF
     String SC_OPCODE_DB { Text = "DB" ; };
     String SC_OPCODE_VBD { Text = "VDB" ; };
     String SC_OPCODE_DURATION { Text = "PDURATION" ; };
-    String SC_OPCODE_LIA { Text = "SLN" ; };
+    String SC_OPCODE_SLN { Text = "SLN" ; };
     String SC_OPCODE_RMZ { Text = "PMT" ; };
     String SC_OPCODE_COLUMNS { Text = "COLUMNS" ; };
     String SC_OPCODE_ROWS { Text = "ROWS" ; };
@@ -623,7 +623,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH_OOXML
     String SC_OPCODE_DB { Text = "DB" ; };
     String SC_OPCODE_VBD { Text = "VDB" ; };
     String SC_OPCODE_DURATION { Text = "_xlfn.PDURATION" ; };
-    String SC_OPCODE_LIA { Text = "SLN" ; };
+    String SC_OPCODE_SLN { Text = "SLN" ; };
     String SC_OPCODE_RMZ { Text = "PMT" ; };
     String SC_OPCODE_COLUMNS { Text = "COLUMNS" ; };
     String SC_OPCODE_ROWS { Text = "ROWS" ; };
@@ -1032,7 +1032,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH
     String SC_OPCODE_DB { Text = "DB" ; };
     String SC_OPCODE_VBD { Text = "VDB" ; };
     String SC_OPCODE_DURATION { Text = "DURATION" ; };
-    String SC_OPCODE_LIA { Text = "SLN" ; };
+    String SC_OPCODE_SLN { Text = "SLN" ; };
     String SC_OPCODE_RMZ { Text = "PMT" ; };
     String SC_OPCODE_COLUMNS { Text = "COLUMNS" ; };
     String SC_OPCODE_ROWS { Text = "ROWS" ; };
@@ -1947,7 +1947,7 @@ Resource RID_STRLIST_FUNCTION_NAMES
     {
         Text [ en-US ] = "DURATION" ;
     };
-    String SC_OPCODE_LIA
+    String SC_OPCODE_SLN
     {
         Text [ en-US ] = "SLN" ;
     };
diff --git a/include/formula/compiler.hrc b/include/formula/compiler.hrc
index 7e9facb..bfbcc70 100644
--- a/include/formula/compiler.hrc
+++ b/include/formula/compiler.hrc
@@ -247,7 +247,7 @@
 #define SC_OPCODE_DB                247
 #define SC_OPCODE_VBD               248
 #define SC_OPCODE_DURATION          249
-#define SC_OPCODE_LIA               250
+#define SC_OPCODE_SLN               250
 #define SC_OPCODE_RMZ               251
 #define SC_OPCODE_COLUMNS           252
 #define SC_OPCODE_ROWS              253
diff --git a/include/formula/opcode.hxx b/include/formula/opcode.hxx
index 2fed555..4ca9893 100644
--- a/include/formula/opcode.hxx
+++ b/include/formula/opcode.hxx
@@ -251,7 +251,7 @@ enum OpCode : sal_uInt16
         ocDB                = SC_OPCODE_DB,
         ocVBD               = SC_OPCODE_VBD,
         ocDuration          = SC_OPCODE_DURATION,
-        ocLIA               = SC_OPCODE_LIA,
+        ocSLN               = SC_OPCODE_SLN,
         ocRMZ               = SC_OPCODE_RMZ,
         ocColumns           = SC_OPCODE_COLUMNS,
         ocRows              = SC_OPCODE_ROWS,
diff --git a/sc/source/core/inc/interpre.hxx b/sc/source/core/inc/interpre.hxx
index 2e7e325..d761a3f 100644
--- a/sc/source/core/inc/interpre.hxx
+++ b/sc/source/core/inc/interpre.hxx
@@ -670,7 +670,7 @@ double ScInterVDB(double fWert,double fRest,double fDauer,double fDauer1,
                 double fPeriode,double fFactor);
 void ScVDB();
 void ScDuration();
-void ScLIA();
+void ScSLN();
 double ScGetRmz(double fZins, double fZzr, double fBw,
                        double fZw, double fF);
 void ScRMZ();
diff --git a/sc/source/core/opencl/formulagroupcl.cxx b/sc/source/core/opencl/formulagroupcl.cxx
index 1116e96..e3704bd 100644
--- a/sc/source/core/opencl/formulagroupcl.cxx
+++ b/sc/source/core/opencl/formulagroupcl.cxx
@@ -2283,7 +2283,7 @@ DynamicKernelSoPArguments::DynamicKernelSoPArguments(
             case ocGamma:
                 mvSubArguments.push_back(SoPHelper(ts, ft->Children[i], new OpGamma, nResultSize));
                 break;
-            case ocLIA:
+            case ocSLN:
                 mvSubArguments.push_back(SoPHelper(ts, ft->Children[i], new OpSLN, nResultSize));
                 break;
             case ocGammaLn:
diff --git a/sc/source/core/tool/interpr2.cxx b/sc/source/core/tool/interpr2.cxx
index 78ce44c..4cfc8ba 100644
--- a/sc/source/core/tool/interpr2.cxx
+++ b/sc/source/core/tool/interpr2.cxx
@@ -1434,7 +1434,7 @@ void ScInterpreter::ScDuration()
     }
 }
 
-void ScInterpreter::ScLIA()
+void ScInterpreter::ScSLN()
 {
     nFuncFmtType = NUMBERFORMAT_CURRENCY;
     if ( MustHaveParamCount( GetByte(), 3 ) )
diff --git a/sc/source/core/tool/interpr4.cxx b/sc/source/core/tool/interpr4.cxx
index 27309a7..badbd9a 100644
--- a/sc/source/core/tool/interpr4.cxx
+++ b/sc/source/core/tool/interpr4.cxx
@@ -4027,7 +4027,7 @@ StackVar ScInterpreter::Interpret()
                 case ocDB               : ScDB();                       break;
                 case ocVBD              : ScVDB();                      break;
                 case ocDuration         : ScDuration();                 break;
-                case ocLIA              : ScLIA();                      break;
+                case ocSLN              : ScSLN();                      break;
                 case ocRMZ              : ScRMZ();                      break;
                 case ocColumns          : ScColumns();                  break;
                 case ocRows             : ScRows();                     break;
diff --git a/sc/source/core/tool/token.cxx b/sc/source/core/tool/token.cxx
index 7edd0d1..b305b8a 100644
--- a/sc/source/core/tool/token.cxx
+++ b/sc/source/core/tool/token.cxx
@@ -1167,7 +1167,7 @@ void ScTokenArray::CheckToken( const FormulaToken& r )
             case ocCount:
             case ocCount2:
             case ocVLookup:
-            case ocLIA:
+            case ocSLN:
             case ocIRR:
             case ocMIRR:
             case ocRMZ:
diff --git a/sc/source/filter/excel/xlformula.cxx b/sc/source/filter/excel/xlformula.cxx
index af5ed56..4deb125 100644
--- a/sc/source/filter/excel/xlformula.cxx
+++ b/sc/source/filter/excel/xlformula.cxx
@@ -189,7 +189,7 @@ static const XclFunctionInfo saFuncTable_2[] =
     { ocN,                  131,    1,  1,  V, { RO }, 0, 0 },
     { ocGetDateValue,       140,    1,  1,  V, { VR }, 0, 0 },
     { ocGetTimeValue,       141,    1,  1,  V, { VR }, 0, 0 },
-    { ocLIA,                142,    3,  3,  V, { VR }, 0, 0 },
+    { ocSLN,                142,    3,  3,  V, { VR }, 0, 0 },
     { ocSYD,                143,    4,  4,  V, { VR }, 0, 0 },
     { ocDDB,                144,    4,  5,  V, { VR }, 0, 0 },
     { ocIndirect,           148,    1,  2,  R, { VR }, EXC_FUNCFLAG_VOLATILE, 0 },
diff --git a/sc/source/filter/lotus/lotform.cxx b/sc/source/filter/lotus/lotform.cxx
index c2dd7a7..550f66a 100644
--- a/sc/source/filter/lotus/lotform.cxx
+++ b/sc/source/filter/lotus/lotform.cxx
@@ -1045,7 +1045,7 @@ DefTokenId LotusToSc::IndexToToken( sal_uInt8 nIndex )
         ocRate,             //  116 Rate()
         ocNoName,           //  117 Term()
         ocNoName,           //  118 Cterm()
-        ocLIA,              //  119 Sln()
+        ocSLN,              //  119 Sln()
         ocSYD,              //  120 Syd(), Soy()
         ocDDB,              //  121 Ddb()
         ocNoName,           //  122
@@ -1574,7 +1574,7 @@ DefTokenId LotusToSc::IndexToTokenWK123( sal_uInt8 nIndex )
         ocRate,             //  116 Rate()
         ocNoName,           //  117 Term()
         ocNoName,           //  118 Cterm()
-        ocLIA,              //  119 Sln()
+        ocSLN,              //  119 Sln()
         ocSYD,              //  120 Syd(), Soy()
         ocDDB,              //  121 Ddb()
         ocNoName,           //  122 Splfunc
diff --git a/sc/source/filter/qpro/qproform.cxx b/sc/source/filter/qpro/qproform.cxx
index bde978e..91f854d 100644
--- a/sc/source/filter/qpro/qproform.cxx
+++ b/sc/source/filter/qpro/qproform.cxx
@@ -491,7 +491,7 @@ static const struct
     { ocZGZ, FT_FuncFix3 }, // Interest
     { ocNoName, FT_NotImpl },
     { ocNoName, FT_NotImpl },
-    { ocLIA, FT_FuncFix3 },
+    { ocSLN, FT_FuncFix3 },
     { ocSYD, FT_FuncFix4 },
     { ocDDB, FT_FuncFix4 },
     { ocStDevP, FT_FuncVar },
diff --git a/sc/source/ui/src/scfuncs.src b/sc/source/ui/src/scfuncs.src
index 24ff46f..86b7608 100644
--- a/sc/source/ui/src/scfuncs.src
+++ b/sc/source/ui/src/scfuncs.src
@@ -1756,8 +1756,8 @@ Resource RID_SC_FUNCTION_DESCRIPTIONS1
             Text [ en-US ] = "Period. The depreciation period which must have the same time unit as average useful life." ;
         };
     };
-     // -=*# Resource for function LIA #*=-
-    Resource SC_OPCODE_LIA
+     // -=*# Resource for function SLN #*=-
+    Resource SC_OPCODE_SLN
     {
         String 1 // Description
         {


More information about the Libreoffice-commits mailing list
diff --git a/sc/source/filter/lotus/lotform.cxx b/sc/source/filter/lotus/lotform.cxx
index 550f66a..60b874a 100644
--- a/sc/source/filter/lotus/lotform.cxx
+++ b/sc/source/filter/lotus/lotform.cxx
@@ -188,11 +188,11 @@ void LotusToSc::DoFunc( DefTokenId eOc, sal_uInt8 nAnz, const sal_Char* pExtStri
 
         sal_Int16 nLast = nAnz - 1;
 
-        if( eOc == ocRMZ )
-        {   // special case ocRMZ, ignore (negate?) last parameter!
+        if( eOc == ocPMT )
+        {   // special case ocPMT, ignore (negate?) last parameter!
             // zusaetzlich: 1. -> 3., 3. -> 2., 2. -> 1.
             OSL_ENSURE( nAnz == 3,
-                "+LotusToSc::DoFunc(): ocRMZ needs 3 parameters!" );
+                "+LotusToSc::DoFunc(): ocPMT needs 3 parameters!" );
             aPool << eParam[ 1 ] << ocSep << eParam[ 0 ] << ocSep
                 << ocNegSub << eParam[ 2 ];
         }
@@ -982,7 +982,7 @@ DefTokenId LotusToSc::IndexToToken( sal_uInt8 nIndex )
         ocRandom,           //   53 Random number
         ocGetDate,          //   54 Date
         ocGetActDate,       //   55 Today
-        ocRMZ,              //   56 Payment
+        ocPMT,              //   56 Payment
         ocPV,               //   57 Present Value
         ocZW,               //   58 Future Value
         ocIf,               //   59 If ... then ... else ...
@@ -1511,7 +1511,7 @@ DefTokenId LotusToSc::IndexToTokenWK123( sal_uInt8 nIndex )
         ocRandom,           //   53 Random number
         ocGetDate,          //   54 Date
         ocGetActDate,       //   55 Today
-        ocRMZ,              //   56 Payment
+        ocPMT,              //   56 Payment
         ocPV,               //   57 Present Value
         ocZW,               //   58 Future Value
         ocIf,               //   59 If... then... else...